@@ -216,21 +216,25 @@ class ConfigProcessor:
             conf[Constants.SASL_PASSWORD] = sasl_password
         return conf
 
-    def get_kafka_schemas(self):
-        key_schema_file = self.get_kafka_key_schema()
-        value_schema_file = self.get_kafka_value_schema()
-
-        from confluent_kafka import avro
-        file = open(key_schema_file, "r")
-        kbytes = file.read()
-        file.close()
-        key_schema = avro.loads(kbytes)
-        file = open(value_schema_file, "r")
-        vbytes = file.read()
-        file.close()
-        val_schema = avro.loads(vbytes)
-
-        return key_schema, val_schema
-
     def get_credmgr_host(self) -> str:
-        return self.config.get_auth().get_credmgr_host()
\ No newline at end of file
+        return self.config.get_auth().get_credmgr_host()
+
+    def get_net_url(self) -> str:
+        if self.config is not None and self.config.get_net() is not None:
+            return self.config.get_net().get_url()
+        return None
+
+    def get_net_username(self) -> str:
+        if self.config is not None and self.config.get_net() is not None:
+            return self.config.get_net().get_username()
+        return None
+
+    def get_net_password(self) -> str:
+        if self.config is not None and self.config.get_net() is not None:
+            return self.config.get_net().get_password()
+        return None
+
+    def get_net_validate_certs(self) -> str:
+        if self.config is not None and self.config.get_net() is not None:
+            return self.config.get_net().get_validate_certs()
+        return None
