@@ -27,6 +27,7 @@ import traceback
 from typing import Tuple
 
 from fabric_cf.actor.core.apis.abc_delegation import DelegationState
+from fabric_cf.actor.core.kernel.slice_state_machine import SliceState
 from fabric_cf.actor.core.manage.error import Error
 from fabric_cf.actor.core.util.id import ID
 from fabric_mb.message_bus.messages.delegation_avro import DelegationAvro
@@ -52,10 +53,8 @@ class ManageCommand(ShowCommand):
 
         try:
             actor.prepare(callback_topic=callback_topic)
-            reservation_id = None
-            if rid is not None:
-                reservation_id = ID(uid=rid)
-            return actor.close_reservation(rid=reservation_id, id_token=id_token), actor.get_last_error()
+            reservation_id = ID(uid=rid) if rid is not None else None
+            return actor.close_reservation(rid=reservation_id), actor.get_last_error()
         except Exception as e:
             self.logger.error(f"Exception occurred e: {e}")
             self.logger.error(traceback.format_exc())
@@ -96,7 +95,7 @@ class ManageCommand(ShowCommand):
 
         try:
             actor.prepare(callback_topic=callback_topic)
-            return actor.close_reservations(slice_id=slice_id, id_token=id_token), actor.get_last_error()
+            return actor.close_reservations(slice_id=slice_id), actor.get_last_error()
         except Exception as e:
             self.logger.error(f"Exception occurred e: {e}")
             self.logger.error(traceback.format_exc())
@@ -140,10 +139,8 @@ class ManageCommand(ShowCommand):
 
         try:
             actor.prepare(callback_topic=callback_topic)
-            reservation_id = None
-            if rid is not None:
-                reservation_id = ID(uid=rid)
-            return actor.remove_reservation(rid=reservation_id, id_token=id_token), actor.get_last_error()
+            reservation_id = ID(uid=rid) if rid is not None else None
+            return actor.remove_reservation(rid=reservation_id), actor.get_last_error()
         except Exception as e:
             self.logger.error(f"Exception occurred e: {e}")
             self.logger.error(traceback.format_exc())
@@ -183,10 +180,8 @@ class ManageCommand(ShowCommand):
 
         try:
             actor.prepare(callback_topic=callback_topic)
-            sid = None
-            if slice_id is not None:
-                sid = ID(uid=slice_id)
-            return actor.remove_slice(slice_id=sid, id_token=id_token), actor.get_last_error()
+            sid = ID(uid=slice_id) if slice_id is not None else None
+            return actor.remove_slice(slice_id=sid), actor.get_last_error()
         except Exception as e:
             self.logger.error(f"Exception occurred e: {e}")
             self.logger.error(traceback.format_exc())
@@ -228,7 +223,7 @@ class ManageCommand(ShowCommand):
         try:
             actor.prepare(callback_topic=callback_topic)
 
-            dlg = actor.claim_delegations(broker=am_guid, did=did, id_token=id_token)
+            dlg = actor.claim_delegations(broker=am_guid, did=did)
             return dlg, actor.get_last_error()
         except Exception as e:
             self.logger.error(f"Exception occurred e: {e}")
@@ -309,7 +304,7 @@ class ManageCommand(ShowCommand):
         try:
             actor.prepare(callback_topic=callback_topic)
 
-            dlg = actor.reclaim_delegations(broker=am_guid, did=did, id_token=id_token)
+            dlg = actor.reclaim_delegations(broker=am_guid, did=did)
             return dlg, actor.get_last_error()
         except Exception as e:
             self.logger.error(f"Exception occurred e: {e}")
@@ -387,8 +382,7 @@ class ManageCommand(ShowCommand):
                 actor.prepare(callback_topic=callback_topic)
 
                 status = actor.toggle_maintenance_mode(actor_guid=str(actor.get_guid()),
-                                                       mode=mode, callback_topic=callback_topic,
-                                                       id_token=id_token)
+                                                       mode=mode, callback_topic=callback_topic)
             except Exception as e:
                 self.logger.error(f"Exception occurred e: {e}")
                 self.logger.error(traceback.format_exc())
@@ -403,3 +397,35 @@ class ManageCommand(ShowCommand):
             print(f"Maintenance mode successfully set to {mode}")
         else:
             print(f"Failure to set maintenance mode error {error}")
+
+    def delete_dead_slices(self, *, actor_name: str, callback_topic: str, id_token: str, email: str):
+
+        try:
+            slices, error = self.do_get_slices(actor_name=actor_name, callback_topic=callback_topic, id_token=id_token,
+                                               email=email, slice_name=None)
+
+            if slices is not None:
+                for s in slices:
+                    state = SliceState(s.get_state())
+                    if state not in [SliceState.Closing, SliceState.Dead]:
+                        continue
+                    print(f"Attempting to remove reservations for slice {s.get_slice_id()} in state {state}")
+                    reservations, error = self.do_get_reservations(actor_name=actor_name, callback_topic=callback_topic,
+                                                                   id_token=id_token, slice_id=s.get_slice_id())
+
+                    if reservations is None:
+                        print(f"No reservations to remove for slice {s.get_slice_id()}")
+                    else:
+                        for r in reservations:
+                            print(f"Attempting to remove reservation: {r.get_reservation_id()}")
+                            self.do_remove_reservation(rid=r.get_reservation_id(), actor_name=actor_name,
+                                                       callback_topic=callback_topic, id_token=id_token)
+
+                    print(f"Attempting to remove slice: {s.get_slice_id()}")
+                    self.remove_slice(slice_id=s.get_slice_id(), actor_name=actor_name,
+                                      callback_topic=callback_topic, id_token=id_token)
+            else:
+                print("No Dead/closing slices to remove")
+        except Exception as e:
+            self.logger.error(f"Exception occurred e: {e}")
+            self.logger.error(traceback.format_exc())
\ No newline at end of file
